@@ -23,6 +23,7 @@ __all__ = [
     'BadPasswordFormatError',
     'BadPasswordSchemeError',
     '__version__',
+    'generate',
     'lookup',
     'make_secret',
     'register',
@@ -30,10 +31,11 @@ __all__ = [
     ]
 
 
-__version__ = '1.0'
+__version__ = '1.1'
 
 
 from ._hash import make_secret
+from ._generate import generate
 from ._registry import BadPasswordSchemeError, lookup, register
 from ._utils import BadPasswordFormatError
 from ._verify import verify
